%%  Copyright (c) 1997, Russel Winder.
%%  With DMTCS-specific alterations by Jeremy Thompson (September 1997)
%%                                     Jens Gustedt (October 1998)
%%  With AlgoTel-specific alterations by =C9ric Fleury (Mars 2000)
%%  Updated by François Durand (November 2021)

% Points to discuss
% =================
% - Keep the "US letter" format or not?
% - Name and style of captions (cf. below).

% Points to improve
% =================
% - Instead of "Author 1 et Author 2 et Author 3", it would 
%   be nicer to have "Author 1, Author 2 et Author 3".
% - The style of the footnote is not the same for a "\thanks"
%   and for a regular footnote.

% Identification
% ==============
\NeedsTeXFormat{LaTeX2e}  
\ProvidesClass{algotel}[2021/11/30 v1.5 Class for AlgoTel articles]  

% Declare options
% ===============
\newcommand \journalacronym{algotel}  
\DeclareOption{11pt}{\ClassError{\journalacronym}{Option `11pt' not supported}{}}  
\DeclareOption{12pt}{\ClassError{\journalacronym}{Option `12pt' not supported}{}}  
\DeclareOption{twocolumn}{\ClassError{\journalacronym}{Option `twocolumn' not supported}{}}  
\ProcessOptions*  
\LoadClassWithOptions{article}

% Load extensions
% ===============
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[
    letterpaper,
    lmargin=3.5cm,
    textwidth=15cm,
    tmargin=4.10cm,
    textheight=22cm,
    headheight=0cm,
    headsep=1cm,
    footskip=2cm,
]{geometry}
\RequirePackage{graphicx}
\RequirePackage{times}  
\RequirePackage{newtxmath}  
\RequirePackage[english, french]{babel}  

% Caption names (necessarily after babel)
% ---------------------------------------
\RequirePackage{silence}
\WarningFilter{caption}{Unknown document class}
\RequirePackage[
    labelsep=colon, 
    figurename=Figure,   % For French
    tablename=Table,    % For French
    labelfont={sc,bf},
    font=small
]{caption}
\addto\captionsenglish{\renewcommand{\figurename}{Figure}}  % For English
\addto\captionsenglish{\renewcommand{\tablename}{Table}}   % For English

% Commands of the class
% =====================

% Dimensions
% ----------
\setlength \textfloatsep{13\p@ \@plus 2\p@ \@minus 4\p@}  
\setlength \parskip{\z@ \@plus 1\p@}  
\setlength \parindent{10\p@}  
\setlength \topsep{4\p@ \@plus 2\p@ \@minus 1\p@}  
\setlength \partopsep{2\p@ \@plus 1\p@ \@minus 1\p@}  

% \title 
% ------

\def \title{\@ifnextchar[{\@gettitletwo}{\@gettitleone}}
\def \@gettitleone#1{\@gettitletwo[#1]{#1}}
\def \@gettitletwo[#1]#2{{%
    \gdef \@title{#2}%
    \def \thanks##1{\relax}%
    \def \\{\unskip \space \ignorespaces}%
    \protected@xdef \@titlehead{#1}%
}}

% Authors and addresses 
% ---------------------

\newcommand \addressmark[1]{%
    \if@marksrequired%
        $^{#1}$%
    \fi%
}

\newif \if@marksrequired

\def \author{\@ifnextchar[{\@getauthortwo}{\@getauthorone}}
\def \@getauthorone#1{\@getauthortwo[#1]{#1}}
\def \@getauthortwo[#1]#2{{%
    \global \@marksrequiredtrue%
    \global \let \latexand \and%
    \gdef \and{\unskip \space \@authorand \space \ignorespaces}%
    \gdef \@author{#2}%
    \def \thanks##1{\relax}%
    \def \\{\unskip \space \ignorespaces}%
    \@marksrequiredfalse%
    \xdef \@authorhead{#1}%
}}

\def \@authorand{et}

\newcommand \address[1]{\gdef \@address{#1}}

% Keywords 
% --------

\def \@keywords{\relax}

\newcommand \keywords[1]{\gdef \@keywords{#1}}

\newcommand \@afterabstract@keywords[1]{%
    \gdef \@keywords{#1}%
    \@dokeywords%
}

\newcommand \@dokeywords{%
    {\small \noindent \textbf{Mots-clefs :} \@keywords \par}%
    \vspace{10\p@}%
    \hrule \@height 1\p@%
    \vspace{10\p@}%
    \global \let \keywords \@gobbleone%
}

\newcommand \trykeywords{%
    \if \relax \@keywords%
        \global \let \keywords \@afterabstract@keywords%
        \vspace{10\p@}%
        \hrule \@height 1\p@%
        \vspace{10\p@}%
    \else%
        \@dokeywords%
    \fi%
}

% Parts and sections 
% ------------------

\renewcommand \part{}
\renewcommand \section{\@startsection {section}{1}{\z@}%
    {-10\p@ \@plus -3\p@ \@minus -2\p@}{6\p@ \@plus 1\p@ \@minus 1\p@}{\sffamily\Large}}
\renewcommand \subsection{\@startsection{subsection}{2}{\z@}%
    {-8\p@ \@plus -2\p@ \@minus -2\p@}{5\p@ \@plus 1\p@ \@minus 1\p@}{\sffamily\large\itshape}}
\renewcommand \subsubsection{\@startsection{subsubsection}{3}{\z@}%
    {-6\p@ \@plus -1 pt \@minus -1\p@}{4\p@ \@plus 1\p@ \@minus 1\p@}{\sffamily\large\itshape}}
\renewcommand \paragraph{\@startsection{paragraph}{4}{\z@}%
    {6\p@ \@plus 1\p@ \@minus -2\p@}{-1em}{\normalsize\bfseries}}
\renewcommand \subparagraph{\@startsection{subparagraph}{4}{\parindent}%
    {6\p@ \@plus 1\p@ \@minus 2\p@}{-1em}{\normalsize\bfseries}}
\renewcommand \appendix{%
    \par%
    \setcounter{section}{0}%
    \setcounter{subsection}{0}%
    \gdef \thesection{\Alph{section}}%
}

% Footnotes 
% ---------

\renewcommand \footnoterule{\kern-3\p@ \hrule \@height 0.8\p@ \kern 2.2\p@}
\long \def \@makefntext#1{\hangindent 7\p@$^{\textrm{\@thefnmark}}$ #1}
\renewcommand \thefootnote{\fnsymbol{footnote}}

% \maketitle 
% ----------

\renewcommand \maketitle{\par%
    \begingroup%
        \def \thefootnote{\fnsymbol{footnote}}%
        \def \@makefnmark{\hb@xt@ \z@{$\m@th^{\@thefnmark}$\hss}\space}%
        \long \def \@makefntext##1{\parindent 1em\noindent
            \hb@xt@ 1.8em{\hss $\m@th^{\@thefnmark}$}##1}%
        \setcounter{footnote}{1}%
        \newpage%
        \global \@topnum \z@%
        \@maketitle%
        \thispagestyle{first}%
        \@thanks%
    \endgroup%
    \global \let \maketitle \relax%
    \global \let \@maketitle \relax%
    \gdef \@thanks{}%
    \gdef \@address{}%
    \gdef \@author{}%
    \gdef \@title{}%
    \global \let \thanks \relax%
}
\newenvironment{titlesp}{%
    \list{}{\leftmargin \z@}\item[]%
}{\endlist}
\def \@maketitle{%
    \newpage%
    \null%
    \begin{titlesp}%
        {\sffamily \raggedright \hyphenpenalty\@M \huge \textit{\@title} \par}%
        \vspace{16\p@}%
        {\Large \@author \par}%
        \vspace{6\p@}%
        {\small \itshape \@address \par}%
        \vspace{6\p@}%
        \vspace{8\p@}%
        \hrule \@height 1\p@%
\vspace{2\p@}%
    \end{titlesp}%
}

% Abstract 
% --------

\def \@firsthead{\relax}

\renewenvironment{abstract}{%
    \begin{titlesp}%
        \small%
}{%
    \end{titlesp}%
    \trykeywords%
}

% If there is no abstract, putting \noabstract instead ensures that keywords are displayed.
% It should not be used, so I comment it (can be removed someday).
% \newcommand \noabstract{\trykeywords}

% Page style 
% ----------
\def \ps@first{%
    \let \@mkboth \@gobbletwo%
    \def \@oddhead{\normalfont \@firsthead \hss}%
    \def \@oddfoot{%
        \vbox to \z@{%
            \hb@xt@ \textwidth{\footnotesize%
              \hss}%
            \vss%
        }%
    }%
    \let \@evenhead \@oddhead%
    \let \@evenfoot \@oddfoot%
    \let \sectionmark \@gobble%
    \let \subsectionmark \@gobble%
}
\def \ps@journal{%
    \let \@mkboth \@gobbletwo%
    \def \@oddhead{%
\normalsize%
\ifodd \c@page%
    \textit{\@titlehead} \hfill% \textrm{\thepage}%
\else%
            %\textrm{\thepage}
            \hfill \textit{\@authorhead}%
        \fi%
    }
    \def \@oddfoot{\vbox to \z@{\vss}}%
    \let \@evenhead \@oddhead%
    \let \@evenfoot \@oddfoot%
    \let \sectionmark \@gobble%
    \let \subsectionmark \@gobble%
}
\pagestyle{journal}
\let \ps@plain \ps@journal
\let \ps@myheadings \ps@journal
\let \ps@headings \ps@journal
\flushbottom

% Misc commands 
% -------------

\newcommand{\qed}{\hfill$\Box$}

% Load hyperref (necessarily last)
% --------------------------------
\RequirePackage[  
    colorlinks=true,  % Colored links (instead of boxes)  
    linkcolor=black,  % Internal links generated by cross-referenced elements, such as Section~\ref{...}  
    citecolor=black,  % For \cite  
    urlcolor=black,   % For \url  
]{hyperref}  

\endinput
%%
%% End of file `algotel.cls'.
